local StoneGateV5 = ...

local myMonument = {
    Id = StoneGateSetPrefix .. "_MONUMENT"
}

_MoverDefaultBuildingPart = "BUILDING_PART_MOVER"

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    StoneGateV5:log("Hello World: version 1.5")
    myMonument.DataType = "MONUMENT"

    _MainBuildingZone = { Polygon = polygon.createRectangle( {8, 12} ) } 
    _KeepBuildingZone = { Polygon = polygon.createRectangle( {8, 8} ) } 
    _SstBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
    _OTowerBuildingZone = { Polygon = polygon.createRectangle( {9, 9} ) } 
    _LGate2BuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 3.5, 3.5 } ) }
    _LGate3BuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 3.5, 3.5 } ) }
    _LGate4BuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 3.5, 3.5 } ) }
    _SGateBuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 0, 3.5 } ) }
    _SGateExtensionBuildingZone = { Polygon = polygon.createRectangle( { 2, 4 }, { 0, 0 } ) }
    _DrawBridgeBuildingZone = { Polygon = polygon.createRectangle( { 2, 2 }, { 0, 0 } ) }
else
    StoneGateV5:log("Hello World: version " .. foundation.getGameVersion())
    myMonument.DataType = "BUILDING"

    -- Apply building asset processor
    StoneGateV5:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

    StoneGateV5:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", StoneGateSetPrefix .. "_CORE_BUILDING_PREFAB")

    -- Register the Core part
    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_CORE_BUILDING_PART",
	Name = StoneGateSetPrefix .. "_CORE_BUILDING_NAME",
	Description = StoneGateSetPrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
    })

    myMonument.AssetCoreBuildingPart = StoneGateSetPrefix .. "_CORE_BUILDING_PART"

    if version.cmp(foundation.getGameVersion(), "1.6.6") < 0 then
        StoneGateV5:log("Hello World: version 1.6.5")
        _MainBuildingZone = { Polygon = polygon.createRectangle( {8, 12} ) } 
        _KeepBuildingZone = { Polygon = polygon.createRectangle( {8, 8} ) } 
        _SstBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
        _OTowerBuildingZone = { Polygon = polygon.createRectangle( {9, 9} ) } 
        _LGate2BuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 3.5, 3.5 } ) }
        _LGate3BuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 3.5, 3.5 } ) }
        _LGate4BuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 3.5, 3.5 } ) }
        _SGateBuildingZone = { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 0, 3.5 } ) }
        _SGateExtensionBuildingZone = { Polygon = polygon.createRectangle( { 2, 4 }, { 0, 0 } ) }
        _DrawBridgeBuildingZone = { Polygon = polygon.createRectangle( { 2, 2 }, { 0, 0 } ) }
    else
        StoneGateV5:log("Hello World: version 1.6.6")
        _MainBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {8, 12} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _KeepBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {8, 8} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _SstBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _OTowerBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createCircle( 4.5, { 0, 0 }, 16 ), -- to be optimized
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _LGate2BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _LGate3BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { -3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _LGate4BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 2, 2 }, { -3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { -3, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _SGateBuildingZone = { ZoneEntryList = { -- deprecated: kept for compatibility
            { Polygon = polygon.createRectangle( { 0.1, 0.1 }, { 0, 3.5 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _SGateExtensionBuildingZone = { ZoneEntryList = { -- deprecated: kept for compatibility
            { Polygon = polygon.createRectangle( { 2, 4 }, { 0, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        _DrawBridgeBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 2, 2 }, { 0, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        StoneGateV5:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")
        StoneGateV5:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")
   end
end

-- Register all stone gate set building parts and their properties
StoneGateV5:dofile("scripts/basicMain.lua")
StoneGateV5:dofile("scripts/basicKeep.lua")
StoneGateV5:dofile("scripts/basicLargeGate.lua")
StoneGateV5:dofile("scripts/basicSmallGate.lua")
StoneGateV5:dofile("scripts/basicSmallSquaredTower.lua")
StoneGateV5:dofile("scripts/basicOctogonalTower.lua")
StoneGateV5:dofile("scripts/hoarding.lua")
StoneGateV5:dofile("scripts/machicolation.lua")
StoneGateV5:dofile("scripts/decoration.lua")
StoneGateV5:dofile("scripts/poleFlag.lua")
StoneGateV5:dofile("scripts/drawBridge.lua")

-- Register the stone gate set monument
myMonument.Name = StoneGateSetPrefix .. "_MONUMENT_NAME"
myMonument.Description = StoneGateSetPrefix .. "_MONUMENT_DESC"
myMonument.BuildingType = "MONUMENT"
myMonument.BuildingPartSetList = {
		{
			Name = StoneGateSetPrefix .. "_MAIN_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_MAIN_ROOT_PART",
		            StoneGateSetPrefix .. "_MAIN_ROOTP_PART",
		            StoneGateSetPrefix .. "_MAIN_ROOF_D_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_A_PART", -- Opened roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_B_PART", -- half opened roof 1
--		            StoneGateSetPrefix .. "_MAIN_ROOF_C_PART", -- deprecated
--		            StoneGateSetPrefix .. "_MAIN_ROOF_E_PART", -- deprecated
		            StoneGateSetPrefix .. "_MAIN_RAMPART_D_PART", -- Closed rampart
		            StoneGateSetPrefix .. "_MAIN_RAMPART_A_PART", -- Opened rampart
		            StoneGateSetPrefix .. "_MAIN_RAMPART_B_PART"--, -- half opened rampart 1
--		            StoneGateSetPrefix .. "_MAIN_RAMPART_C_PART"  -- deprecated
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_KEEP_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_KEEP_ROOT_PART",
		            StoneGateSetPrefix .. "_KEEP_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_ROOT_PART",
-- Deprecated		            StoneGateSetPrefix .. "_LGATEB_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_3_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_3_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_4_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_4_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEP_ROOF_C_PART", -- Closed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_D_PART", -- 1 side opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_B_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_E_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_A_PART", -- 3 sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_F_PART", -- all sides opened
-- deprecated		            StoneGateSetPrefix .. "_KEEP_ROOF_G_PART", 
		            StoneGateSetPrefix .. "_KEEP_RAMPART_C_PART", -- Closed roof
		            StoneGateSetPrefix .. "_KEEP_RAMPART_D_PART", -- 1 side opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_B_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_E_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_A_PART", -- 3 sides opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_F_PART"  -- all sides opened
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_HOARDING_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_HOARDING_S2L0R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S2L0R1_PART",
		            StoneGateSetPrefix .. "_HOARDING_S2L1R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S2L1R1_PART",
		            StoneGateSetPrefix .. "_EXTENSION_S2L0R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L0R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L0R1_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L1R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L1R1_PART",
		            StoneGateSetPrefix .. "_EXTENSION_S3L0R0_PART"
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_MACHICOLATION_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_MACHICOLATION_KEEP_C_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_KEEP_C_P_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION34_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION40R_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION40L_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION50_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_KEEP_ROOF_C_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_MAIN_D_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_MAIN_D_P_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION54_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION60R_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION60L_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION70_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_MAIN_ROOF_D_PART"
		        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SST_ROOT_PART",
		            StoneGateSetPrefix .. "_SST_ROOTP_PART",
		            StoneGateSetPrefix .. "_SST_ROOF_A_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SST_ROOF_B_PART",  -- 1 side opened roof
--		            StoneGateSetPrefix .. "_SST_ROOF_C_PART",  -- deprecated
		            StoneGateSetPrefix .. "_SST_ROOF_D_PART",  -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_E_PART",  -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_F_PART",  -- 3 sides opened
		            StoneGateSetPrefix .. "_SST_RAMPART_A_PART",  -- Close rampart
		            StoneGateSetPrefix .. "_SST_RAMPART_B_PART",   -- 1 side opened rampart
		            StoneGateSetPrefix .. "_SST_RAMPART_C_PART",   -- 1 side closed rampart
		            StoneGateSetPrefix .. "_HOARDING_S1_A_PART",
		            StoneGateSetPrefix .. "_HOARDING_S1_B_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_A_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_B_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_AP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_BP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_A_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_B_PART", -- 1 side opened roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_D_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_STAIR_A_PART",   -- stairs with stone floor
		            StoneGateSetPrefix .. "_SST_STAIR_B_PART",   -- stairs with wooden floor
		            StoneGateSetPrefix .. "_SST_STAIR_C_PART",   -- stairs foundation with stone floor
		            StoneGateSetPrefix .. "_SST_STAIR_D_PART",   -- stairs foundation with wooden floor
		            StoneGateSetPrefix .. "_SST_BRIDGE1_PART",   -- simple bridge part with stone floor
		            StoneGateSetPrefix .. "_SST_BRIDGE1P_PART",  -- simple bridge part with wooden floor
		            StoneGateSetPrefix .. "_SST_HALF_ARCH1_PART",-- Small half arch bridge part
		            StoneGateSetPrefix .. "_SST_HALF_ARCH2_PART",-- Large half arch bridge part
         	            StoneGateSetPrefix .. "_SST_RAMPART_D_PART", -- 1 side for stairs
		            StoneGateSetPrefix .. "_SST_RAMPART_E_PART"  -- 1 side for stairs
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SGATE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SGATE_ROOT_PART",
		            StoneGateSetPrefix .. "_SGATE_EXT_ROOT_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOT_P_PART",
		            StoneGateSetPrefix .. "_SGATE_EXT_ROOT_P_PART",
		            StoneGateSetPrefix .. "_SGATE_RAMPART_A_PART",
		            StoneGateSetPrefix .. "_SGATE_RAMPART_CLOSING_L_PART",
		            StoneGateSetPrefix .. "_SGATE_RAMPART_CLOSING_R_PART",
		            StoneGateSetPrefix .. "_SGATE_HOARDING_A_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_A_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_B_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_CLOSING_L_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_CLOSING_R_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_WOODEN_ROOF_A_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_STONE_ROOF_A_PART"
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_OTOWER_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_OTOWER_ROOT_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOTB_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOF_PART",
--		            StoneGateSetPrefix .. "_OTOWER_ROOFB_PART", -- deprecated
		            StoneGateSetPrefix .. "_OTOWER_RAMPART_PART", -- all sides
		            StoneGateSetPrefix .. "_OTOWER_RAMPART_B_PART", -- one side
		            StoneGateSetPrefix .. "_OTOWER_RAMPART_C_PART", -- one side open
		            StoneGateSetPrefix .. "_OTOWER_HOARDING_PART",
		            StoneGateSetPrefix .. "_OTOWER_HOARDING_EXT_PART",
		            StoneGateSetPrefix .. "_OTOWER_MACHICOLATION_PART",
		            StoneGateSetPrefix .. "_OTOWER_MACHICOLATION_B_PART",
		            StoneGateSetPrefix .. "_OTOWER_MACHICOLATION_ROOF_PART"
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_ENTRANCE_PARTSETLIST_NAME",
	                BuildingPartList = {
 		            StoneGateSetPrefix .. "_ENTRANCE_DOOR_A_PART",
  		            StoneGateSetPrefix .. "_ENTRANCE_DOOR_B_PART"
                       }
                },
                {
			Name = StoneGateSetPrefix .. "_BRIDGE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_A_CORE_PART",
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_B_CORE_PART",
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_HARROW_PART"
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_DECORATION_PARTSETLIST_NAME",
	                BuildingPartList = {
		            "STONE_GATE_V5_DECORATION_SFENETRE_PART",
		            "STONE_GATE_V5_DECORATION_LFENETRE_PART",
		            "STONE_GATE_V5_DECORATION_PFENETRE_PART",
		            "STONE_GATE_V5_DECORATION_ARROWSLIT_PART",
		            "STONE_GATE_V5_DECORATION_BALCONY_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_A_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_B_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_MA_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_MB_PART",
		            StoneGateSetPrefix .. "_DECORATION_BUTTRESS_PART",
		            StoneGateSetPrefix .. "_DECORATION_CHIMNEY_BASE_PART",
		            "STONE_GATE_V5_DECORATION_CHIMNEY_PART",
		            "STONE_GATE_V5_DECORATION_LUCARNE_PART",
		            StoneGateSetPrefix .. "_DECORATION_POINTED_ROOF_BASE_PART",
		            "STONE_GATE_V5_DECORATION_LARGE_LUCARNE_PART",
		            "STONE_GATE_V5_DECORATION_TURRET_PART",
		            "STONE_GATE_V5_DECORATION_STONE_ROUND_WINDOW_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_RED_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_BLUE_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_GREEN_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_PURPLE_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_ORANGE_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_TURQUOISE_ROOT_PART",
		            "STONE_GATE_V5_DECORATION_FINIAL1_PART",
		            "STONE_GATE_V5_DECORATION_FINIAL2_PART",
		            "STONE_GATE_V5_DECORATION_FINIAL3_PART",
--		            StoneGateSetPrefix .. "_DECORATION_PINION_A_PART", -- deprecated
		            StoneGateSetPrefix .. "_DECORATION_PINION_B_PART",
		            StoneGateSetPrefix .. "_DECORATION_PINION_C_PART", -- simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_D_PART", -- simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_E_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_F_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_G_PART", -- simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_H_PART", -- small simple stone pinion
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_WINDOW_1_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_1_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_2_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_3_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_4_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_8_PART",
		            "STONE_GATE_V5_DECORATION_SPLENDOR_2_PART",
		            "STONE_GATE_V5_DECORATION_P_STAINED_GLASS_1_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_TALL_1_PART",
		            "STONE_GATE_V5_DECORATION_STAINED_GLASS_TALL_2_PART"
                        }
                }                  
}
myMonument.RequiredPartList = {
		-- Necessarily a list of 'MONUMENT_REQUIRED_PART_PAIR', no need to specify the DataType of each element of the list
		{ Category = "CORE", Quantity = 1 }
}
myMonument.MaterialSetList = {
            {
                SetName = StoneGateSetPrefix .. "_RED_ROOF", -- default materials
                MaterialList = {
                    StoneGateSetPrefix .. "_DECORATION_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MAIN_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_KEEP_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SST_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SGATE_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_OTOWER_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_MAIN_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_KEEP_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SST_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SGATE_RED_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_OTOWER_RED_ROOF_MATERIAL"
                }
            },
            {
                SetName = StoneGateSetPrefix .. "_BLUE_ROOF",
                MaterialList = {
                    StoneGateSetPrefix .. "_DECORATION_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MAIN_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_KEEP_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SST_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SGATE_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_OTOWER_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_MAIN_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_KEEP_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SST_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SGATE_BLUE_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_OTOWER_BLUE_ROOF_MATERIAL"
                }
            },
            {
                SetName = StoneGateSetPrefix .. "_BROWN_ROOF",
                MaterialList = {
                    StoneGateSetPrefix .. "_DECORATION_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MAIN_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_KEEP_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SST_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SGATE_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_OTOWER_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_MAIN_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_KEEP_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SST_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SGATE_BROWN_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_OTOWER_BROWN_ROOF_MATERIAL"
                }
            },
            {
                SetName = StoneGateSetPrefix .. "_GREY_ROOF",
                MaterialList = {
                    StoneGateSetPrefix .. "_DECORATION_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MAIN_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_KEEP_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SST_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SGATE_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_OTOWER_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_MAIN_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_KEEP_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SST_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SGATE_GREY_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_OTOWER_GREY_ROOF_MATERIAL"
                }
            },
            {
                SetName = StoneGateSetPrefix .. "_GREY2_ROOF",
                MaterialList = {
                    StoneGateSetPrefix .. "_DECORATION_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MAIN_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_KEEP_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SST_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_SGATE_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_OTOWER_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_MAIN_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_KEEP_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SST_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_SGATE_GREY2_ROOF_MATERIAL",
                    StoneGateSetPrefix .. "_MACHICOLATION_OTOWER_GREY2_ROOF_MATERIAL"
                }
            }
}
myMonument.IsEditable = true

-- Register the Stone Gate Set monument
StoneGateV5:register(myMonument)

